# -*- Mode: rpm-spec -*-
#
# (c) Mandriva
#
# The kernel-2.6-linus package (and so this spec file) is under development,
# it does mean:
#
#    1. You can have nasty surprises when playing with the package
#    generation
#
#    2. Is easier to go and come back from Mordor than adding a new
#    architecture support
#
#    3. A known architecture with just a missing .config shouldn't be too
#    hard, but as this spec changes too fast, it's likely to be broken
# 
#
# if you try to understand kernel numbering, read docs/kernel_naming

%define sublevel 18
%define mdvrelease 1
%define use_patch rc7
#define patchlevel 1
%define klinus_notice NOTE: This kernel has no Mandriva patches and no third-party drivers.

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-tmb :)
%define kname kernel-linus

# You shouldn't have to change any other name/patch/version number
%define major 6

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %use_patch
%define kversion 2.%{major}.%(expr %{sublevel} - 1)
%define realrelease %{use_patch}.%{mdvrelease}%{?patchlevel:.%{patchlevel}}%distsuffix
%else
%define kversion 2.%{major}.%{sublevel}
%define realrelease %{mdvrelease}%{?patchlevel:.%{patchlevel}}%distsuffix
%endif

# never touch the folowing two fields
%define rpmversion 1
%define rpmrelease %mkrel 1
%define krealversion 2.%{major}.%{sublevel}
%define mdvversion %{krealversion}.%{realrelease}

# having different top level names for packges means
# that you have to remove them by hard :(
%define top_dir_name %{kname}-2.%{major}

%define build_dir ${RPM_BUILD_DIR}/%top_dir_name
%define src_dir %{build_dir}/linux-%kversion
%define KVERREL %{krealversion}-%{realrelease}

%define build_kheaders 0
%define build_debug 0
%define build_doc 1
%define build_source 1

%define distro_branch %(perl -pe '/(\\d+)\\.(\\d)\\.?(\\d)?/; $_="$1.$2"' /etc/mandrake-release)
%define build_101 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.1 ];then echo 1; else echo 0; fi)
%define build_100 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.0 ];then echo 1; else echo 0; fi)
%define build_92 %(if [ `awk '{print $4}' /etc/mandrake-release` = 9.2 ];then echo 1; else echo 0; fi)

%define build_up 1
%define build_smp 1

%define build_secure 0

%ifarch %{ix86}
%define build_i586_up_1GB 0
%define build_i686_up_4GB 0
%define build_xbox 0
%else
%define build_i586_up_1GB 0
%define build_i686_up_4GB 0
%define build_xbox 0
%endif

%ifarch powerpc
%define build_power5 1
%define build_ppc970 0
%if ! %{build_ppc970}
# default to build for power5 only
%define build_up     0
%define build_smp    0
%endif
%else
%define build_power5 0
%endif

# disable useless debug rpms...
%define _enable_debug_packages	%{nil}
%define debug_package		%{nil}

# End of user definitions
%{?_without_up: %global build_up 0}
%{?_without_smp: %global build_smp 0}
%{?_without_secure: %global build_secure 0}
%{?_without_i586up1GB: %global build_i586_up_1GB 0}
%{?_without_i686up4GB: %global build_i686_up_4GB 0}
%{?_without_xbox: %global build_xbox 0}
%{?_without_debug: %global build_debug 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}

%{?_with_up: %global build_up 1}
%{?_with_smp: %global build_smp 1}
%{?_with_secure: %global build_secure 1}
%{?_with_i586up1GB: %global build_i586_up_1GB 1}
%{?_with_i686up4GB: %global build_i686_up_4GB 1}
%{?_with_xbox: %global build_xbox 1}
%{?_with_debug: %global build_debug 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}

%{?_with_kheaders: %global build_kheaders 1}
%{?_with_92: %global build_92 1}
%{?_with_100: %global build_100 1}
%{?_with_101: %global build_101 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make CC="$CC"
%else
%define kmake %make 
%endif
# there are places where parallel make don't work
%define smake make

# Aliases for amd64 builds (better make source links?)
%define target_cpu	%(echo %{_target_cpu} | sed -e "s/amd64/x86_64/")
%define target_arch	%(echo %{_arch} | sed -e "s/amd64/x86_64/" -e "s/sparc/%{_target_cpu}/")

Summary: 	The Linux kernel (the core of the Linux operating system)
Name: 		%{kname}-%{mdvversion}
Version: 	%{rpmversion}
Release: 	%{rpmrelease}
License: 	GPL
Group: 		System/Kernel and hardware
ExclusiveArch: 	%{ix86} alpha ppc powerpc ia64 x86_64 amd64 sparc sparc64
ExclusiveOS: 	Linux
URL: 		http://www.kernel.org/

####################################################################
#
# Sources
#
Source0:  ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/linux-%{kversion}.tar.bz2
Source1:  ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/linux-%{kversion}.tar.bz2.sign
Source4:  README.kernel-sources
Source5:  README.MandrivaLinux
Source15: kernel-linus-mdvconfig.h
Source16: linux-merge-config.awk
Source17: update_configs
Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-smp.config
Source22: kernel-%{kversion}-x86_64.config
Source23: kernel-%{kversion}-x86_64-smp.config
Source24: kernel-%{kversion}-sparc64.config
Source25: kernel-%{kversion}-sparc64-smp.config
Source26: kernel-%{kversion}-ppc.config
Source27: kernel-%{kversion}-ppc-smp.config


####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v2.%{major}/testing

%if %use_patch
Patch1: patch-%krealversion-%use_patch.bz2
Source2: patch-%krealversion-%use_patch.bz2.sign
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
%define requires1 module-init-tools >= 3.0-%mkrel 7
%define requires2 mkinitrd >= 3.4.43-%mkrel 10
%if %{build_100}
%define requires3 bootloader-utils >= 1.6
%else
%define requires3 bootloader-utils >= 1.9
%endif
%define requires4 sysfsutils module-init-tools >= 0.9.15

%define kprovides kernel = %{krealversion}, alsa

BuildRoot: 	%{_tmppath}/%{name}-%{krealversion}-build
Provides: 	module-info, %kprovides
Autoreqprov: 	no
Requires: 	%requires1
Requires: 	%requires2
Requires: 	%requires3
Requires: 	%requires4
BuildRequires: 	gcc module-init-tools >= 0.9.15

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandriva Linux operating system. The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-smp: Symmetric MultiProcessing kernel
#

%package -n %{kname}-smp-%{mdvversion}
Summary:  The Linux Kernel compiled for SMP machines
Group: 	  System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-smp-%{mdvversion}
This package includes a SMP version of the Linux %{krealversion} kernel. It is
required only on machines with two or more CPUs, although it should work
fine on single-CPU boxes.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-secure-%{mdvversion}
Summary:  The Linux Kernel compiled for SECURE machines
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-secure-%{mdvversion}
This package includes a SECURE version of the Linux %{krealversion}
kernel. This package add options for kernel that make it more secure
for servers and such. See :

http://www.nsa.gov/selinux/

for list of features we have included.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-xbox: XBox kernel
# 

%package -n %{kname}-xbox-%{mdvversion}
Summary:  The version of the Linux kernel used on XBox machines
Group:    System/Kernel and hardware
Url:      http://peoples.mandriva.com/~sbenedict/XBox/
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-xbox-%{mdvversion}
This package includes a modified version of the Linux kernel.
This kernel is used for XBox machines only and should not
be used for a normal x86 machine.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i586-up-1GB-%{mdvversion}
Summary:  The Linux Kernel compiled for up with less than 1GB
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i586-up-1GB-%{mdvversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical single processor desktop with up to 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-up-4GB-%{mdvversion}
Summary:  The Linux Kernel compiled for up with 4GB
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-up-4GB-%{mdvversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical single processor machine with memory 
between 1GB and 4GB.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-up-1GB-%{mdvversion}
Summary:  The Linux Kernel compiled for up with less than 1GB
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-up-1GB-%{mdvversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical single processor machine with less 
than 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-i686-smp-1GB-%{mdvversion}
Summary:  The Linux Kernel compiled for up with less than 1GB
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-i686-smp-1GB-%{mdvversion}
This package includes a kernel that has appropriate configuration 
options enabled for the typical multi processor (or Hyper-Threading) 
machines with less than 1GB of memory.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# kernel-power5: Power5 kernel
#

%package -n %{kname}-power5-%{mdvversion}
Summary:  The POWER5 optimized kernel
Group:    System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-power5-%{mdvversion}
The kernel-power5 package contains the POWER5 optimized kernel for
IBM OpenPower series systems.

%{klinus_notice}

#
# kernel-source: kernel sources
#

%package -n %{kname}-source-%{mdvversion}
Version:  %{rpmversion}
Release:  %{rpmrelease}
Provides: %{kname}-source, kernel-source
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary:  The source code for the Linux kernel
Group:    Development/Kernel
Autoreqprov: no
Conflicts: %{kname}-source-stripped-%{mdvversion}

%description -n %{kname}-source-%{mdvversion}
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

%package -n %{kname}-source-stripped-%{mdvversion}
Version:  %{rpmversion}
Release:  %{rpmrelease}
Provides: %{kname}-source, kernel-source
Provides: %{kname}-source-2.%{major}
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary:  The source code of the Linux kernel stripped for post build
Group:    Development/Kernel
Autoreqprov: no
Conflicts: %{kname}-source-%{mdvversion}

%description -n %{kname}-source-stripped-%{mdvversion}
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

%{klinus_notice}

#
# kernel-doc: documentation for the Linux kernel
#

%package -n %{kname}-doc-%{mdvversion}
Version: %{version}
Release: %{release}
Summary: Various documentation bits found in the kernel source
Group:   Books/Computer books

%description -n %{kname}-doc-%{mdvversion}
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

For instructions for update, see:
http://www.mandriva.com/security/kernelupdate

%{klinus_notice}

#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

pushd %src_dir
%if %use_patch
%patch1 -p1
%endif
popd

# Put here patchlevel patches

# PATCH END
#
# Setup Begin
#

pushd ${RPM_SOURCE_DIR}

# FIXME: The right way to it would be the loop only running through the arch's
# .config files. But the kernel build functions (defined in the %build
# section) expect the .config files exactly the way the current loop does.
# The build functions need to be fixed first.
for i in kernel-%{kversion}-*.config; do
	cp $i %{build_dir}/linux-%{kversion}/arch/%{target_arch}/$(basename $i)
done
popd

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" linux-%{kversion}/Makefile

# get rid of unwanted files
# XXX: This was used in the previous mdv's kernel, doesn't seem needed any
# more. Let's keep it commented for now, can be totally removed if after
# more testing.
# find . -name '*~' -o -name '*.orig' -o -name '*.append' |xargs rm -f

%if %build_kheaders

kheaders_dirs=`echo $PWD/linux-%{kversion}/include/{asm-*,linux,sound}`

install -d kernel-headers/
cp -a $kheaders_dirs kernel-headers/
tar cf kernel-headers-%mdvversion.tar kernel-headers/
bzip2 -9f kernel-headers-%mdvversion.tar
rm -rf kernel-headers/
# build_kheaders
%endif

%build
# Common target directories
%define _kerneldir /usr/src/linux-%{KVERREL}
%define _bootdir /boot
%ifarch ia64
%define _efidir %{_bootdir}/efi/mandriva
%endif
%define _modulesdir /lib/modules
%define _savedheaders ../../savedheaders/

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}

PrepareKernel() {
	name=$1
	extension=$2
	# FIXME: Should be removed when we adopt a standard name for the
        # .config files
	config_name="kernel-%{kversion}-%{target_arch}.config"
	echo "Prepare compilation of kernel $extension"

	# We can't use only defconfig anymore because we have the autoconf patch,

	if [ "$name" ]; then
		config_name="kernel-%{kversion}-%{target_arch}-$name.config"
	fi

	# make sure EXTRAVERSION says what we want it to say
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION =.*/EXTRAVERSION = -$extension/" Makefile

	%smake -s mrproper
	cp arch/%{target_arch}/$config_name .config
	%smake oldconfig
}

BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake all

	## Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

	%ifarch alpha
	cp -f arch/alpha/boot/vmlinux.gz %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch ia64
       	install -d %{temp_root}%{_efidir}
       	cp -f vmlinux.gz %{temp_root}%{_efidir}/vmlinuz-$KernelVer
       	pushd %{temp_boot}
       	ln -s %{_efidir}/vmlinuz-$KernelVer vmlinuz-$KernelVer
       	popd
       	%endif
	%ifarch sparc sparc64
	gzip -9c vmlinux > %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch ppc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch %{ix86}
	cp -f arch/i386/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch x86_64
	cp -f arch/x86_64/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif
	%ifarch powerpc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	%endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install 
}

SaveHeaders() {
	flavour=$1
	flavour_name="`echo $flavour | sed 's/-/_/g'`"
%if %build_source
	HeadersRoot=%{temp_source}/savedheaders
	HeadersArch=$HeadersRoot/%{target_cpu}/$flavour
	echo "Saving hearders for $flavour %{target_cpu}"

	# deal with the kernel headers that are version specific
	install -d $HeadersArch
	install -m 644 include/linux/autoconf.h $HeadersArch/autoconf.h
	install -m 644 include/linux/version.h $HeadersArch/version.h
    	echo "%{target_cpu} $flavour_name %{_savedheaders}%{target_cpu}/$flavour/" >> $HeadersRoot/list
%endif
}

CreateFiles() {
	kernversion=$1
	output=../kernel_files.$kernversion

	echo "%defattr(-,root,root)" > $output
	echo "%{_bootdir}/config-${kernversion}" >> $output
	echo "%{_bootdir}/vmlinuz-${kernversion}" >> $output
%ifarch ia64
	echo "%{_efidir}/vmlinuz-${kernversion}" >> $output
%endif
	echo "%{_bootdir}/System.map-${kernversion}" >> $output
	echo "%dir %{_modulesdir}/${kernversion}/" >> $output
	echo "%{_modulesdir}/${kernversion}/kernel" >> $output
	echo "%{_modulesdir}/${kernversion}/modules.*" >> $output
	echo "%doc README.kernel-sources" >> $output
	echo "%doc README.MandrivaLinux" >> $output
}

CreateKernel() {
	flavour=$1

	if [ "$flavour" = "up" ]; then
		KernelVer=%{KVERREL}
		PrepareKernel "" %realrelease
	elif [ "$flavour" = "power5" ]; then
		KernelVer=%{KVERREL}p5
		PrepareKernel $flavour %{realrelease}p5
	else
		KernelVer=%{KVERREL}$flavour
		PrepareKernel $flavour %{realrelease}$flavour
	fi

	BuildKernel $KernelVer
	SaveHeaders $flavour
        CreateFiles $KernelVer
}


CreateKernelNoName() {
	arch=$1
	nprocs=$2
	memory=$3

        name=$arch-$nprocs-$memory
	extension="%realrelease-$name"

	KernelVer="%{KVERREL}-$arch-$nprocs-$memory"
	PrepareKernel $name $extension
	BuildKernel $KernelVer
	SaveHeaders $name
        CreateFiles $KernelVer
}

###
# DO it...
###

# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}

#make sure we are in the directory
cd %src_dir

%if %build_power5
CreateKernel power5
%endif

%if %build_smp
CreateKernel smp
%endif

%if %build_i586_up_1GB
CreateKernelNoName i586 up 1GB
%endif

%if %build_i686_up_4GB
CreateKernelNoName i686 up 4GB
%endif

%if %build_xbox
CreateKernel xbox
%endif

%if %build_up
CreateKernel up
%endif

# We don't make to repeat the depend code at the install phase
%if %build_source
PrepareKernel "" %{realrelease}custom
# From > 2.6.13 prepare-all is deprecated and relies on include/linux/autoconf
# To have modpost and others scripts, one has to use the target scripts
%smake -s prepare
%smake -s scripts
%endif

###
### install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .

cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source} 

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in arm cris mips mips64 parisc s390 s390x sh sh64 arm26 h8300 m68knommu v850 m32r frv; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i
done
# ppc needs m68k headers
rm -rf %{target_source}/arch/m68k

# remove config split dir contents
rm -rf %{target_source}/include/config/*

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.tmp_gas_check}

pushd %{target_source}/include/linux ; {
install -m 644 %{SOURCE15} rhconfig.h
rm -rf autoconf.h version.h

# Create autoconf.h file
echo '#include <linux/rhconfig.h>' > autoconf.h
sed 's,$,autoconf.h,' %{_savedheaders}list | awk -f %{SOURCE16} >> autoconf.h

# From 2.6.18-rcX onward autoconf setup is being reworked,
# /include/linux/autoconf.h is replaced with 
# /include/config/auto.conf and several other changes...
# FIXME: For now use autoconf.h to create auto.conf
grep '#' autoconf.h >>../config/auto.conf

# Create version.h
echo "#include <linux/rhconfig.h>" > version.h
loop_cnt=0
for i in up smp secure i686-up-4GB i686-up-1GB i686-smp-1GB i586-up-1GB power5; do
	if [ -d %{_savedheaders}%{target_cpu}/$i -a \
	     -f %{_savedheaders}%{target_cpu}/$i/version.h ]; then
		name=`echo $i | sed 's/-/_/g'`
		if [ $loop_cnt = 0 ]; then
      			buf="#if defined(__module__$name)"
    		else
 	     		buf="#elif defined(__module__$name)"
    		fi
		echo "$buf" >> version.h
		#XXX: Should we really remove 'custom'?
		grep UTS_RELEASE utsrelease.h | sed -e 's/custom//' >> version.h
		loop_cnt=$[loop_cnt + 1]
	fi
done
#write last lines
if [ $loop_cnt -eq 0 ]; then
	echo "You need to build at least one kernel"
	exit 1;
fi
echo "#else" >> version.h
echo '#define UTS_RELEASE "'%{KVERREL}custom'"' >> version.h
echo "#endif" >> version.h

# From 2.6.18-rcX onward autoconf setup is being reworked,
# UTS_RELEASE defines in /include/linux/version.h
# has been moved to /include/linux/utsrelease.h
# FIXME: For now we simply duplicate the code
rm -rf utsrelease.h
cp version.h utsrelease.h

# Any of the version.h are ok, as they only differ in the first line
ls %{_savedheaders}%{target_cpu}/*/version.h | head -n 1 | xargs grep -v UTS_RELEASE >> version.h
rm -rf %{_savedheaders}
} ; popd
#endif %build_source
%endif

# gzipping modules
find %{target_modules} -name "*.ko" | xargs gzip -9

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be

for i in %{target_modules}/*; do
  rm -f $i/build $i/source $i/modules.*
done

# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here

pushd %{target_modules}
for i in *; do
	/sbin/depmod-25 -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	modules=`find . -name "*.ko.gz"`
	echo $modules | xargs /sbin/modinfo-25 \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd

###
### clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be 
# able to do several rpm --short-circuit -bi for testing install 
# phase without repeating compilation phase
#rm -rf %{temp_root} 

###
### scripts
###

%if %{build_100}
%define options_preun -a -R -S -c
%define options_post  -a -s -c
%else
%define options_preun -R
#%define options_post -C
%endif

%preun
/sbin/installkernel %options_preun %{KVERREL}
exit 0

%post
/sbin/installkernel %options_post %{KVERREL}

%postun
/sbin/kernel_remove_initrd %{KVERREL}


%preun -n %{kname}-smp-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}smp
exit 0

%post -n %{kname}-smp-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}smp

%postun -n %{kname}-smp-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}smp

%preun -n %{kname}-xbox-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}xbox
exit 0

%post -n %{kname}-xbox-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}xbox

%postun -n %{kname}-xbox-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}xbox

%preun -n %{kname}-secure-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}secure
exit 0

%post -n %{kname}-secure-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}secure

%postun -n %{kname}-secure-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}secure


%preun -n %{kname}-i586-up-1GB-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}-i586-up-1GB
exit 0

%post -n %{kname}-i586-up-1GB-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}-i586-up-1GB

%postun -n %{kname}-i586-up-1GB-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}-i586-up-1GB


%preun -n %{kname}-i686-up-4GB-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-up-4GB
exit 0

%post -n %{kname}-i686-up-4GB-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}-i686-up-4GB

%postun -n %{kname}-i686-up-4GB-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-up-4GB


%preun -n %{kname}-i686-up-1GB-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-up-1GB
exit 0

%post -n %{kname}-i686-up-1GB-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}-i686-up-1GB

%postun -n %{kname}-i686-up-1GB-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-up-1GB

%preun -n %{kname}-i686-smp-1GB-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}-i686-smp-1GB
exit 0

%post -n %{kname}-i686-smp-1GB-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}-i686-smp-1GB

%postun -n %{kname}-i686-smp-1GB-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}-i686-smp-1GB


%preun -n %{kname}-power5-%{mdvversion}
/sbin/installkernel %options_preun %{KVERREL}p5
exit 0

%post -n %{kname}-power5-%{mdvversion}
/sbin/installkernel %options_post %{KVERREL}p5

%postun -n %{kname}-power5-%{mdvversion}
/sbin/kernel_remove_initrd %{KVERREL}p5


%post -n %{kname}-source-%{mdvversion}
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
		ln -sf /usr/src/linux-%{KVERREL} $i/source
	fi
done

%postun -n %{kname}-source-%{mdvversion}
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/build at unsinstall
for i in /lib/modules/%{KVERREL}*/{build,source}; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

%post -n %{kname}-source-stripped-%{mdvversion}
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
		ln -sf /usr/src/linux-%{KVERREL} $i/source
	fi
done

%postun -n %{kname}-source-stripped-%{mdvversion}
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/{build,source} at unsinstall
for i in /lib/modules/%{KVERREL}*/{build,source}; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

###
### file lists
###

%if %build_up
%files -f kernel_files.%{KVERREL}
%endif

%if %build_smp
%files -n %{kname}-smp-%{mdvversion} -f kernel_files.%{KVERREL}smp
%endif

%if %build_xbox
%files -n %{kname}-xbox-%{mdvversion} -f kernel_files.%{KVERREL}xbox
%endif

%if %build_secure
%files -n %{kname}-secure-%{mdvversion} -f kernel_files.%{KVERREL}secure
%endif

%if %build_i586_up_1GB
%files -n %{kname}-i586-up-1GB-%{mdvversion} -f kernel_files.%{KVERREL}-i586-up-1GB
%endif

%if %build_i686_up_4GB
%files -n %{kname}-i686-up-4GB-%{mdvversion} -f kernel_files.%{KVERREL}-i686-up-4GB
%endif

%if %build_power5
%files -n %{kname}-power5-%{mdvversion} -f kernel_files.%{KVERREL}p5
%endif


%if %build_source
%files -n %{kname}-source-%{mdvversion}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/.gitignore
%{_kerneldir}/Kbuild
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/alpha
%{_kerneldir}/arch/i386
%{_kerneldir}/arch/ia64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/powerpc
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%{_kerneldir}/arch/x86_64
%{_kerneldir}/arch/xtensa
%{_kerneldir}/arch/um
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/fs
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/security
%{_kerneldir}/scripts
%{_kerneldir}/sound
%{_kerneldir}/usr
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%{_kerneldir}/include/asm-alpha
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/asm-i386
%{_kerneldir}/include/asm-ia64
# This is needed by ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-powerpc
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%{_kerneldir}/include/asm-x86_64
%{_kerneldir}/include/asm-xtensa
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/config
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/mtd
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/keys
%{_kerneldir}/include/rdma
%doc README.kernel-sources
%doc README.MandrivaLinux

# source-stripped
%files -n %{kname}-source-stripped-%{mdvversion}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/alpha
%{_kerneldir}/arch/i386
%{_kerneldir}/arch/ia64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/powerpc
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%{_kerneldir}/arch/x86_64
%{_kerneldir}/arch/um
%{_kerneldir}/drivers/char
%{_kerneldir}/drivers/scsi
%{_kerneldir}/scripts
%{_kerneldir}/usr
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%{_kerneldir}/include/asm-alpha
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/asm-i386
%{_kerneldir}/include/asm-ia64
# This is needed by ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-powerpc
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%{_kerneldir}/include/asm-x86_64
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/config
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/rxrpc
%doc README.kernel-sources
%doc README.MandrivaLinux
#endif %build_source
%endif

%if %build_doc
%files -n %{kname}-doc-%{mdvversion}
%defattr(-,root,root)
%doc linux-%{kversion}/Documentation/*
%endif



%changelog
### REMOVE THE PATCHLEVEL DEFINITION ABOVE ###
* Wed Sep 13 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc7-1mdv
- update to 2.6.a8-rc7

* Wed Sep  6 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc6-3mdv
- fix spec for missing UTS_RELEASE (#24889)

* Tue Sep  5 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc6-2mdv
- fix autoconf UTS_RELEASE relocation from version.h to 
  utsrelease.h (#24889)

* Mon Sep  4 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc6-1mdv
- update to 2.6.18-rc6
- fix rpmlint warnings

* Sun Sep  3 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc5.6mdv
- change source15 to fix autoconf part that bootloader-utils-1.13
  broke (#24889)
- fix autoconf to work with 2.6.18 series auto.conf (#24889)
- stop building useless debug rpms
- spec cleanup  s/mdk/mdv/g
- update README.kernel-sources 
- use mkrel and distsuffix to make it work for backports
- source and source-stripped needs to conflict each other

* Mon Aug 28 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc5-5mdv
- Updates to 2.6.18-rc5
- update defconfigs
- fix target_arch on sparc64 (pkarlsen@mandriva.com)

* Tue Aug  8 2006 Thomas Backlund <tmb@mandriva.org> 2.6.18-rc4-4mdv
- Updates to 2.6.18-rc4
- Spec cleaning
- update defconfigs
- update README files
- fix previous changelog year s/2008/2006/g

* Tue Jul 18 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-07-18 20:38:40 (41569)
- Updates to 2.6.18-rc2

* Sun Jul 09 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-07-09 16:54:32 (38600)
- Updates to 2.6.18-rc1

* Tue Jun 20 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-06-20 15:23:55 (37658)
- Updates to 2.6.17
- Version reset: when I started with kernel-linus I wasn't too
  experienced with RPM packages and thought that packages' version
  should never been reset. Doing it now.

* Fri Jun 09 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-06-09 15:44:06 (36901)
- Adds new Mandriva tag

* Tue Jun 06 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-06-06 16:20:10 (36699)
- Updates to 2.6.17-rc6

* Mon May 29 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-05-29 14:36:37 (31646)
- renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

* Thu May 25 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-05-25 17:05:48 (31590)
- Updates to 2.6.17-rc5

* Fri May 12 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-05-12 15:49:33 (27159)
- Updates to 2.6.17-rc4

* Mon May 08 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-05-08 22:18:55 (27006)
- Fixes 'kernel-source is upgraded but kernel is not' bug (#21345)

* Thu May 04 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-05-04 21:20:52 (26917)
- Introduces PPC support, patch and .config files from Christiaan Welvaart
  <cjw@daneel.dyndns.org>

* Thu May 04 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-05-04 20:07:28 (26913)
- x86 .configs update, the following changes have been made:
    o OBSOLETE and non-sense options have been disabled
    o New drivers and other interesting options (which were probably
      not automatically enabled by the bot) have been enabled
    o SMP kernel now supports: cpusets, 32 CPUs and 64 GB of memory

* Fri Apr 28 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-28 16:21:36 (26756)
- Updates sparc64 .config files, patch from Per Oyvind Karlsen
  <pkarlsen@mandriva.com>

* Thu Apr 27 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-27 23:02:25 (26741)
- Updates to 2.6.17-rc3

* Wed Apr 26 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-26 21:04:42 (26694)
- Updates sparc64 .config files, patch from Per Oyvind Karlsen
  <pkarlsen@mandriva.com>

* Wed Apr 26 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-26 21:02:18 (26693)
- This patch makes kernel image 'gzipped', it's needed to make it
  boot properly (and also makes sparc's kernel image consistent with
  other archs). Patch from Per Oyvind Karlsen <pkarlsen@mandriva.com>.

* Wed Apr 19 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-19 15:31:31 (26557)
- Updates to 2.6.17-rc2

* Tue Apr 04 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-04 20:41:08 (26277)
- Updates sparc64 .config files, patch from Per Oyvind Karlsen
  <pkarlsen@mandriva.com>

* Mon Apr 03 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-04-03 19:15:29 (26268)
- Updates to 2.6.17-rc1

* Mon Mar 20 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-03-20 17:13:33 (26030)
- Updates to 2.6.16

* Fri Mar 17 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-03-17 19:06:45 (26002)
- Minor typo

* Sun Mar 12 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-03-12 16:42:36 (1942)
- Updates to 2.6.16-rc6

* Tue Feb 28 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-28 01:09:44 (1817)
- Updates to 2.6.16-rc5

* Tue Feb 21 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-21 14:47:10 (1800)
- Changes to the kernel's stack to 8k bytes, as this question is polemic
  in two sides (proprietary drivers and performance) let's stay with the
  kernel's default.

* Sun Feb 19 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-19 19:53:40 (1789)
- - Updates to 2.6.16-rc4

* Wed Feb 15 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-15 21:35:55 (1741)
- New version

* Wed Feb 15 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-15 13:45:39 (1738)
- Changes some SMP options as suggested by Arnaud Patard <apatard@mandriva.com>
  basically, we're dropping BKL preemption support (because this is not
  supposed to only run on desktop systems), enabling software suspend and
  CPU hotpluging.

* Tue Feb 14 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-14 16:44:07 (1736)
- Introduces sparc64 support (patches from Per Oyvind Karlsen
  <pkarlsen@mandriva.com>)

* Mon Feb 13 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-13 16:49:28 (1730)
- Updates to 2.6.16-rc3

* Fri Feb 10 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-10 18:23:18 (1724)
- Some times I'm really stupid: forgot to add the spec changelog entry
  and to change the package's version on r1723.

* Fri Feb 10 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-10 18:14:00 (1723)
- Enables CONFIG_CC_OPTIMIZE_FOR_SIZE, to try to get a smaller kernel and
  other benefits.

* Fri Feb 03 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-02-03 13:51:35 (1566)
- Introduces 'update_configs' script (from mdv2006 stable kernel)
- Updates to 2.6.16-rc2

* Sat Jan 28 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-28 17:12:11 (1493)
- Minor log fix
- Commit in behalf of Oden Eriksson <oeriksson@mandriva.com>:
  - Fixes kernel headers generation
  - Fixes SUBLEVEL change in the kernel`s Makefile
  - Minor cleanups

* Fri Jan 27 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-27 19:23:09 (1492)
- Improves klinus_notice

* Thu Jan 26 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-26 20:00:11 (1480)
- Adds a note (in the package description) about kernel-linus's nature

* Thu Jan 19 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-19 17:20:01 (1442)
- Minor log fix, rpm prints some warnings with you write '%%prep' in the
  changelog section

* Wed Jan 18 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-18 22:57:31 (1441)
- Fixes embarrassing bug which causes any *.config file to be copied
  to the build directory
- Comments out removal of unwanted files in %%prep section, this doesn't
  seen to be needed anymore and can cause to wanted files to be removed too
- Adds comments in the top file about kernel-linus known issues

* Wed Jan 18 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-18 21:22:00 (1440)
- New spec file name (kernel-2.6.spec is already used by other package)
- Adds all the kernel's .config file as 'Source', that way they're
  included in the src.rpm

* Tue Jan 17 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-17 16:26:42 (1436)
- Updates to 2.6.16-rc1

* Mon Jan 16 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-16 20:54:13 (1432)
- Updating package version, this will be the next release

* Sun Jan 15 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-15 20:47:24 (1429)
- Merges kernel-2.6-linus simplifications into the trunk
  (svn merge -r 1362:1428 svn+ssh://svn.mandriva.com/svn/mdv/branches/cooker/kernel-2.6-linus/current .)

* Thu Jan 05 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-05 18:04:27 (1380)
- Disables CONFIG_HWMON_DEBUG_CHIP, it's only interesting for
  developers

* Thu Jan 05 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-05 17:44:32 (1379)
- Provides kernel-source package should provides 'kernel-source', this
  makes life easier when using dkms

* Tue Jan 03 2006 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2006-01-03 13:40:22 (1359)
- Minor log fix
- Updates to 2.6.15

* Fri Dec 30 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-30 16:42:34 (1356)
- Fixes kernel-source package generation

* Wed Dec 28 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-28 19:17:07 (1353)
- Updates TODO list

* Wed Dec 28 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-28 19:12:46 (1352)
- Enables compilation for more architectures
- s/ppc64/powerpc/
- Minor %%patchlevel fix

* Tue Dec 27 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-27 18:32:49 (1351)
- Fixes Makefile hardcoded values
- Updated to 2.6.15-rc7

* Tue Dec 27 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-27 13:18:43 (1349)
- Fixes Makefile hardcoded values

* Mon Dec 26 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-26 17:56:36 (1346)
- reverts r1345 and r1344. I was going to update the package for 2.6.15-rc7
  but there are some things to be done before, like a new release and tons
  of fixes.

* Mon Dec 26 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-26 13:35:00 (1345)
- Updates .config files for 2.6.15-rc7

* Mon Dec 26 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-26 13:21:13 (1344)
- Updates to 2.6.15-rc7
- Enables more archs
- Minor Changes

* Thu Dec 22 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-22 19:52:16 (1343)
- Introduces TODO list

* Thu Dec 22 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-22 18:57:21 (1342)
- Minor spec file fixes
- Changes package name to 'kernel-linus'
- Update version

* Thu Dec 22 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-22 13:26:14 (1336)
- Fixes br0ken compile with our current i386.config

* Wed Dec 21 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-21 21:28:55 (1330)
- Update hardcoded value to make the thing compile

* Wed Dec 21 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-21 20:21:15 (1327)
- This is a new package, removes all the changelog entries and adds the
  relevant one

* Wed Dec 21 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-21 20:10:37 (1326)
- Err, time-stamp are created automatically during build time, this files
  pulled in at the initial import step.. They shouldn't be here.

* Wed Dec 21 2005 Luiz Fernando Capitulino <lcapitulino@mandriva.com>
+ 2005-12-21 19:30:42 (1325)
- Introduces 'kernel-2.6-linus' RPM package source tree. This new package
  will provide the latest -rc kernels from Linus.
